<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------
if (!defined('DC_RC_PATH')) { return; }

$__resources['rss_news'] = 'http://fr.dotclear.org/blog/feed/category/News/atom';

$__resources['doc'] = array(
	"Accueil de l'aide Dotclear" => 'http://fr.dotclear.org/documentation/2.0',
	'Présentation de Dotclear' => 'http://doc.dotclear.net/2.0/overview/tour',
	"Manuel de l'utilisateur" => 'http://doc.dotclear.net/2.0/usage',
	"Guide d'installation et d'administration" => 'http://doc.dotclear.net/2.0/admin',
	"Forum de support de Dotclear" => 'http://forum.dotclear.net/'
);
?>